# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.24.0~53ca673',
    built_at='2023-05-30 11:45:40Z',
    sha='53ca6734597979602ec2a3330b4bdcc1a712721a',
    branch='HEAD',
    tag='v3.24.0',
)
